@@ -5,6 +5,8 @@ multidict. It behaves mostly like a dict but it can have
 several values for the same key.
 """
 
+from typing import TYPE_CHECKING
+
 from ._abc import MultiMapping, MutableMultiMapping
 from ._compat import USE_EXTENSIONS
 
@@ -20,21 +22,10 @@ __all__ = (
     "getversion",
 )
 
-__version__ = "6.0.4"
+__version__ = "6.6.4"
 
 
-try:
-    if not USE_EXTENSIONS:
-        raise ImportError
-    from ._multidict import (
-        CIMultiDict,
-        CIMultiDictProxy,
-        MultiDict,
-        MultiDictProxy,
-        getversion,
-        istr,
-    )
-except ImportError:  # pragma: no cover
+if TYPE_CHECKING or not USE_EXTENSIONS:
     from ._multidict_py import (
         CIMultiDict,
         CIMultiDictProxy,
@@ -43,6 +34,26 @@ except ImportError:  # pragma: no cover
         getversion,
         istr,
     )
+else:
+    from collections.abc import ItemsView, KeysView, ValuesView
+
+    from ._multidict import (
+        CIMultiDict,
+        CIMultiDictProxy,
+        MultiDict,
+        MultiDictProxy,
+        _ItemsView,
+        _KeysView,
+        _ValuesView,
+        getversion,
+        istr,
+    )
+
+    MultiMapping.register(MultiDictProxy)
+    MutableMultiMapping.register(MultiDict)
+    KeysView.register(_KeysView)
+    ItemsView.register(_ItemsView)
+    ValuesView.register(_ValuesView)
 
 
 upstr = istr
